Class: VoucherifySdk::ClientValidationsValidateResponseBody

Inherits:
Object
  • Object
show all
Defined in:
lib/VoucherifySdk/models/client_validations_validate_response_body.rb

Overview

Response body schema for POST /validations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClientValidationsValidateResponseBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 91

def initialize(attributes = {})
  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  end

  if attributes.key?(:'redeemables')
    if (value = attributes[:'redeemables']).is_a?(Array)
      self.redeemables = value
    end
  end

  if attributes.key?(:'skipped_redeemables')
    if (value = attributes[:'skipped_redeemables']).is_a?(Array)
      self.skipped_redeemables = value
    end
  end

  if attributes.key?(:'inapplicable_redeemables')
    if (value = attributes[:'inapplicable_redeemables']).is_a?(Array)
      self.inapplicable_redeemables = value
    end
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  end

  if attributes.key?(:'session')
    self.session = attributes[:'session']
  end

  if attributes.key?(:'stacking_rules')
    self.stacking_rules = attributes[:'stacking_rules']
  else
    self.stacking_rules = nil
  end
end

Instance Attribute Details

#idObject

Unique identifier of the validation, assigned by Voucherify.



20
21
22
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 20

def id
  @id
end

#inapplicable_redeemablesObject

Lists validation results of each inapplicable redeemable.



31
32
33
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 31

def inapplicable_redeemables
  @inapplicable_redeemables
end

#orderObject

Returns the value of attribute order.



33
34
35
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 33

def order
  @order
end

#redeemablesObject

Returns the value of attribute redeemables.



25
26
27
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 25

def redeemables
  @redeemables
end

#sessionObject

Returns the value of attribute session.



38
39
40
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 38

def session
  @session
end

#skipped_redeemablesObject

Lists validation results of each skipped redeemable.



28
29
30
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 28

def skipped_redeemables
  @skipped_redeemables
end

#stacking_rulesObject

Returns the value of attribute stacking_rules.



40
41
42
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 40

def stacking_rules
  @stacking_rules
end

#tracking_idObject

Hashed customer source ID.



36
37
38
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 36

def tracking_id
  @tracking_id
end

#validObject

The result of the validation. It takes all of the redeemables into account and returns a false if at least one redeemable is inapplicable. Returns true if all redeemables are applicable.



23
24
25
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 23

def valid
  @valid
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 217

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = VoucherifySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 58

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'valid' => :'valid',
    :'redeemables' => :'redeemables',
    :'skipped_redeemables' => :'skipped_redeemables',
    :'inapplicable_redeemables' => :'inapplicable_redeemables',
    :'order' => :'order',
    :'tracking_id' => :'tracking_id',
    :'session' => :'session',
    :'stacking_rules' => :'stacking_rules'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
82
83
84
85
86
87
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 78

def self.openapi_nullable
  Set.new([
    :'id',
    :'valid',
    :'redeemables',
    :'skipped_redeemables',
    :'inapplicable_redeemables',
    :'tracking_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 63

def self.openapi_types
  {
    :'id' => :'String',
    :'valid' => :'Boolean',
    :'redeemables' => :'Array<ClientValidationsValidateResponseBodyRedeemablesItem>',
    :'skipped_redeemables' => :'Array<ValidationsRedeemableSkipped>',
    :'inapplicable_redeemables' => :'Array<ValidationsRedeemableInapplicable>',
    :'order' => :'OrderCalculated',
    :'tracking_id' => :'String',
    :'session' => :'Session',
    :'stacking_rules' => :'StackingRules'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      valid == o.valid &&
      redeemables == o.redeemables &&
      skipped_redeemables == o.skipped_redeemables &&
      inapplicable_redeemables == o.inapplicable_redeemables &&
      order == o.order &&
      tracking_id == o.tracking_id &&
      session == o.session &&
      stacking_rules == o.stacking_rules
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 288

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 186

def hash
  [id, valid, redeemables, skipped_redeemables, inapplicable_redeemables, order, tracking_id, session, stacking_rules].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @stacking_rules.nil?
    invalid_properties.push('invalid value for "stacking_rules", stacking_rules cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 264

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 270

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



258
259
260
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 258

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
# File 'lib/VoucherifySdk/models/client_validations_validate_response_body.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @stacking_rules.nil?
  true
end