Class: VoucherifySdk::Discount

Inherits:
Object
  • Object
show all
Defined in:
lib/VoucherifySdk/models/discount.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Discount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/VoucherifySdk/models/discount.rb', line 161

def initialize(attributes = {})
  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'amount_off')
    self.amount_off = attributes[:'amount_off']
  end

  if attributes.key?(:'amount_off_formula')
    self.amount_off_formula = attributes[:'amount_off_formula']
  end

  if attributes.key?(:'aggregated_amount_limit')
    self.aggregated_amount_limit = attributes[:'aggregated_amount_limit']
  end

  if attributes.key?(:'effect')
    self.effect = attributes[:'effect']
  end

  if attributes.key?(:'is_dynamic')
    self.is_dynamic = attributes[:'is_dynamic']
  end

  if attributes.key?(:'unit_off')
    self.unit_off = attributes[:'unit_off']
  end

  if attributes.key?(:'unit_off_formula')
    self.unit_off_formula = attributes[:'unit_off_formula']
  end

  if attributes.key?(:'unit_type')
    self.unit_type = attributes[:'unit_type']
  end

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  end

  if attributes.key?(:'units')
    if (value = attributes[:'units']).is_a?(Array)
      self.units = value
    end
  end

  if attributes.key?(:'percent_off')
    self.percent_off = attributes[:'percent_off']
  end

  if attributes.key?(:'percent_off_formula')
    self.percent_off_formula = attributes[:'percent_off_formula']
  end

  if attributes.key?(:'amount_limit')
    self.amount_limit = attributes[:'amount_limit']
  end

  if attributes.key?(:'fixed_amount')
    self.fixed_amount = attributes[:'fixed_amount']
  end

  if attributes.key?(:'fixed_amount_formula')
    self.fixed_amount_formula = attributes[:'fixed_amount_formula']
  end
end

Instance Attribute Details

#aggregated_amount_limitObject

Maximum discount amount per order.



27
28
29
# File 'lib/VoucherifySdk/models/discount.rb', line 27

def aggregated_amount_limit
  @aggregated_amount_limit
end

#amount_limitObject

Upper limit allowed to be applied as a discount. Value is multiplied by 100 to precisely represent 2 decimal places. For example, a $6 maximum discount is written as 600.



56
57
58
# File 'lib/VoucherifySdk/models/discount.rb', line 56

def amount_limit
  @amount_limit
end

#amount_offObject

Amount taken off the subtotal of a price. Value is multiplied by 100 to precisely represent 2 decimal places. For example, a $10 discount is written as 1000.



21
22
23
# File 'lib/VoucherifySdk/models/discount.rb', line 21

def amount_off
  @amount_off
end

#amount_off_formulaObject

Formula used to dynamically calculate the discount.



24
25
26
# File 'lib/VoucherifySdk/models/discount.rb', line 24

def amount_off_formula
  @amount_off_formula
end

#effectObject

Returns the value of attribute effect.



29
30
31
# File 'lib/VoucherifySdk/models/discount.rb', line 29

def effect
  @effect
end

#fixed_amountObject

Sets a fixed value for an order total or the item price. The value is multiplied by 100 to precisely represent 2 decimal places. For example, a $10 discount is written as 1000. If the fixed amount is calculated by the formula, i.e. the fixed_amount_formula parameter is present in the fixed amount definition, this value becomes the fallback value. As a result, if the formula cannot be calculated due to missing metadata, for example, this value will be used as the fixed value.



59
60
61
# File 'lib/VoucherifySdk/models/discount.rb', line 59

def fixed_amount
  @fixed_amount
end

#fixed_amount_formulaObject

Formula used to dynamically calculate the discount.



62
63
64
# File 'lib/VoucherifySdk/models/discount.rb', line 62

def fixed_amount_formula
  @fixed_amount_formula
end

#is_dynamicObject

Flag indicating whether the discount was calculated using a formula.



32
33
34
# File 'lib/VoucherifySdk/models/discount.rb', line 32

def is_dynamic
  @is_dynamic
end

#percent_offObject

The percent discount that the customer will receive.



50
51
52
# File 'lib/VoucherifySdk/models/discount.rb', line 50

def percent_off
  @percent_off
end

#percent_off_formulaObject

Formula used to dynamically calculate the discount.



53
54
55
# File 'lib/VoucherifySdk/models/discount.rb', line 53

def percent_off_formula
  @percent_off_formula
end

#productObject

Returns the value of attribute product.



43
44
45
# File 'lib/VoucherifySdk/models/discount.rb', line 43

def product
  @product
end

#skuObject

Returns the value of attribute sku.



45
46
47
# File 'lib/VoucherifySdk/models/discount.rb', line 45

def sku
  @sku
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/VoucherifySdk/models/discount.rb', line 18

def type
  @type
end

#unit_offObject

Number of units to be granted a full value discount.



35
36
37
# File 'lib/VoucherifySdk/models/discount.rb', line 35

def unit_off
  @unit_off
end

#unit_off_formulaObject

Formula used to dynamically calculate the number of units.



38
39
40
# File 'lib/VoucherifySdk/models/discount.rb', line 38

def unit_off_formula
  @unit_off_formula
end

#unit_typeObject

The product deemed as free, chosen from product inventory (e.g. time, items).



41
42
43
# File 'lib/VoucherifySdk/models/discount.rb', line 41

def unit_type
  @unit_type
end

#unitsObject

Returns the value of attribute units.



47
48
49
# File 'lib/VoucherifySdk/models/discount.rb', line 47

def units
  @units
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/VoucherifySdk/models/discount.rb', line 320

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = VoucherifySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/VoucherifySdk/models/discount.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/VoucherifySdk/models/discount.rb', line 87

def self.attribute_map
  {
    :'type' => :'type',
    :'amount_off' => :'amount_off',
    :'amount_off_formula' => :'amount_off_formula',
    :'aggregated_amount_limit' => :'aggregated_amount_limit',
    :'effect' => :'effect',
    :'is_dynamic' => :'is_dynamic',
    :'unit_off' => :'unit_off',
    :'unit_off_formula' => :'unit_off_formula',
    :'unit_type' => :'unit_type',
    :'product' => :'product',
    :'sku' => :'sku',
    :'units' => :'units',
    :'percent_off' => :'percent_off',
    :'percent_off_formula' => :'percent_off_formula',
    :'amount_limit' => :'amount_limit',
    :'fixed_amount' => :'fixed_amount',
    :'fixed_amount_formula' => :'fixed_amount_formula'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/VoucherifySdk/models/discount.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/VoucherifySdk/models/discount.rb', line 138

def self.openapi_nullable
  Set.new([
    :'type',
    :'amount_off',
    :'amount_off_formula',
    :'aggregated_amount_limit',
    :'effect',
    :'is_dynamic',
    :'unit_off',
    :'unit_off_formula',
    :'unit_type',
    :'product',
    :'units',
    :'percent_off',
    :'percent_off_formula',
    :'amount_limit',
    :'fixed_amount',
    :'fixed_amount_formula'
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/VoucherifySdk/models/discount.rb', line 115

def self.openapi_types
  {
    :'type' => :'String',
    :'amount_off' => :'Float',
    :'amount_off_formula' => :'String',
    :'aggregated_amount_limit' => :'Integer',
    :'effect' => :'String',
    :'is_dynamic' => :'Boolean',
    :'unit_off' => :'Integer',
    :'unit_off_formula' => :'String',
    :'unit_type' => :'String',
    :'product' => :'DiscountProduct',
    :'sku' => :'SimpleSkuDiscountUnit',
    :'units' => :'Array<DiscountUnitMultipleOneUnit>',
    :'percent_off' => :'Float',
    :'percent_off_formula' => :'String',
    :'amount_limit' => :'Float',
    :'fixed_amount' => :'Float',
    :'fixed_amount_formula' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/VoucherifySdk/models/discount.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      amount_off == o.amount_off &&
      amount_off_formula == o.amount_off_formula &&
      aggregated_amount_limit == o.aggregated_amount_limit &&
      effect == o.effect &&
      is_dynamic == o.is_dynamic &&
      unit_off == o.unit_off &&
      unit_off_formula == o.unit_off_formula &&
      unit_type == o.unit_type &&
      product == o.product &&
      sku == o.sku &&
      units == o.units &&
      percent_off == o.percent_off &&
      percent_off_formula == o.percent_off_formula &&
      amount_limit == o.amount_limit &&
      fixed_amount == o.fixed_amount &&
      fixed_amount_formula == o.fixed_amount_formula
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/VoucherifySdk/models/discount.rb', line 391

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/VoucherifySdk/models/discount.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/VoucherifySdk/models/discount.rb', line 289

def hash
  [type, amount_off, amount_off_formula, aggregated_amount_limit, effect, is_dynamic, unit_off, unit_off_formula, unit_type, product, sku, units, percent_off, percent_off_formula, amount_limit, fixed_amount, fixed_amount_formula].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



240
241
242
243
244
# File 'lib/VoucherifySdk/models/discount.rb', line 240

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
# File 'lib/VoucherifySdk/models/discount.rb', line 367

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/VoucherifySdk/models/discount.rb', line 373

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



361
362
363
# File 'lib/VoucherifySdk/models/discount.rb', line 361

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



248
249
250
251
252
253
254
255
# File 'lib/VoucherifySdk/models/discount.rb', line 248

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["AMOUNT", "UNIT", "PERCENT", "FIXED"])
  return false unless type_validator.valid?(@type)
  effect_validator = EnumAttributeValidator.new('String', ["APPLY_TO_ORDER", "APPLY_TO_ITEMS", "APPLY_TO_ITEMS_PROPORTIONALLY", "APPLY_TO_ITEMS_PROPORTIONALLY_BY_QUANTITY", "APPLY_TO_ITEMS_BY_QUANTITY", "ADD_MISSING_ITEMS", "ADD_NEW_ITEMS", "ADD_MANY_ITEMS", "ADD_SAME_ITEMS"])
  return false unless effect_validator.valid?(@effect)
  true
end