Class: VoucherifySdk::EarningRule

Inherits:
Object
  • Object
show all
Defined in:
lib/VoucherifySdk/models/earning_rule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EarningRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 176

def initialize(attributes = {})
  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'loyalty')
    self.loyalty = attributes[:'loyalty']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'custom_event')
    self.custom_event = attributes[:'custom_event']
  end

  if attributes.key?(:'segment')
    self.segment = attributes[:'segment']
  end

  if attributes.key?(:'loyalty_tier')
    self.loyalty_tier = attributes[:'loyalty_tier']
  end

  if attributes.key?(:'pending_points')
    self.pending_points = attributes[:'pending_points']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = 'earning_rule'
  end

  if attributes.key?(:'automation_id')
    self.automation_id = attributes[:'automation_id']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiration_date')
    self.expiration_date = attributes[:'expiration_date']
  end

  if attributes.key?(:'validity_timeframe')
    self.validity_timeframe = attributes[:'validity_timeframe']
  end

  if attributes.key?(:'validity_day_of_week')
    if (value = attributes[:'validity_day_of_week']).is_a?(Array)
      self.validity_day_of_week = value
    end
  end

  if attributes.key?(:'validity_hours')
    self.validity_hours = attributes[:'validity_hours']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'expiration_rules')
    self.expiration_rules = attributes[:'expiration_rules']
  end

  if attributes.key?(:'validation_rule_id')
    self.validation_rule_id = attributes[:'validation_rule_id']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end
end

Instance Attribute Details

#activeObject

A flag to toggle the earning rule on or off. You can disable an earning rule even though it's within the active period defined by the start_date and expiration_date of the campaign or the earning rule's own start_date and expiration_date. - true indicates an active earning rule - false indicates an inactive earning rule



69
70
71
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 69

def active
  @active
end

#automation_idObject

For internal use by Voucherify.



42
43
44
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 42

def automation_id
  @automation_id
end

#created_atObject

Timestamp representing the date and time when the earning rule was created. The value is shown in the ISO 8601 format.



22
23
24
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 22

def created_at
  @created_at
end

#custom_eventObject

Returns the value of attribute custom_event.



28
29
30
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 28

def custom_event
  @custom_event
end

#eventObject

Returns the value of attribute event.



26
27
28
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 26

def event
  @event
end

#expiration_dateObject

Expiration date defines when the earning rule expires. Expiration timestamp is presented in the ISO 8601 format. The earning rule is inactive after this date. If you do not define the expiration date for an earning rule, it will inherit the campaign expiration date by default.



48
49
50
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 48

def expiration_date
  @expiration_date
end

#expiration_rulesObject

Returns the value of attribute expiration_rules.



60
61
62
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 60

def expiration_rules
  @expiration_rules
end

#idObject

Assigned by the Voucherify API, identifies the earning rule object.



19
20
21
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 19

def id
  @id
end

#loyaltyObject

Returns the value of attribute loyalty.



24
25
26
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 24

def loyalty
  @loyalty
end

#loyalty_tierObject

Returns the value of attribute loyalty_tier.



32
33
34
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 32

def loyalty_tier
  @loyalty_tier
end

#metadataObject

The metadata object stores all custom attributes assigned to the earning rule. A set of key/value pairs that you can attach to an earning rule object. It can be useful for storing additional information about the earning rule in a structured format.



58
59
60
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 58

def 
  @metadata
end

#objectObject

The type of the object represented by JSON. Default is earning_rule.



39
40
41
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 39

def object
  @object
end

#pending_pointsObject

Returns the value of attribute pending_points.



34
35
36
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 34

def pending_points
  @pending_points
end

#segmentObject

Returns the value of attribute segment.



30
31
32
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 30

def segment
  @segment
end

#sourceObject

Returns the value of attribute source.



36
37
38
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 36

def source
  @source
end

#start_dateObject

Start date defines when the earning rule starts to be active. Activation timestamp is presented in the ISO 8601 format. The earning rule is inactive before this date. If you do not define the start date for an earning rule, it will inherit the campaign start date by default.



45
46
47
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 45

def start_date
  @start_date
end

#updated_atObject

Timestamp representing the date and time when the earning rule was last updated in ISO 8601 format.



66
67
68
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 66

def updated_at
  @updated_at
end

#validation_rule_idObject

A unique validation rule identifier assigned by the Voucherify API. The validation rule is verified before points are added to the balance.



63
64
65
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 63

def validation_rule_id
  @validation_rule_id
end

#validity_day_of_weekObject

Integer array corresponding to the particular days of the week in which the voucher is valid. - 0 Sunday - 1 Monday - 2 Tuesday - 3 Wednesday - 4 Thursday - 5 Friday - 6 Saturday



53
54
55
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 53

def validity_day_of_week
  @validity_day_of_week
end

#validity_hoursObject

Returns the value of attribute validity_hours.



55
56
57
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 55

def validity_hours
  @validity_hours
end

#validity_timeframeObject

Returns the value of attribute validity_timeframe.



50
51
52
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 50

def validity_timeframe
  @validity_timeframe
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 355

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = VoucherifySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



121
122
123
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 121

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 94

def self.attribute_map
  {
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'loyalty' => :'loyalty',
    :'event' => :'event',
    :'custom_event' => :'custom_event',
    :'segment' => :'segment',
    :'loyalty_tier' => :'loyalty_tier',
    :'pending_points' => :'pending_points',
    :'source' => :'source',
    :'object' => :'object',
    :'automation_id' => :'automation_id',
    :'start_date' => :'start_date',
    :'expiration_date' => :'expiration_date',
    :'validity_timeframe' => :'validity_timeframe',
    :'validity_day_of_week' => :'validity_day_of_week',
    :'validity_hours' => :'validity_hours',
    :'metadata' => :'metadata',
    :'expiration_rules' => :'expiration_rules',
    :'validation_rule_id' => :'validation_rule_id',
    :'updated_at' => :'updated_at',
    :'active' => :'active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 153

def self.openapi_nullable
  Set.new([
    :'id',
    :'created_at',
    :'loyalty',
    :'custom_event',
    :'segment',
    :'loyalty_tier',
    :'pending_points',
    :'source',
    :'object',
    :'automation_id',
    :'start_date',
    :'expiration_date',
    :'metadata',
    :'validation_rule_id',
    :'updated_at',
    :'active'
  ])
end

.openapi_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 126

def self.openapi_types
  {
    :'id' => :'String',
    :'created_at' => :'Time',
    :'loyalty' => :'EarningRuleLoyalty',
    :'event' => :'String',
    :'custom_event' => :'EarningRuleCustomEvent',
    :'segment' => :'EarningRuleSegment',
    :'loyalty_tier' => :'EarningRuleLoyaltyTier',
    :'pending_points' => :'EarningRulePendingPoints',
    :'source' => :'EarningRuleSource',
    :'object' => :'String',
    :'automation_id' => :'String',
    :'start_date' => :'String',
    :'expiration_date' => :'String',
    :'validity_timeframe' => :'ValidityTimeframe',
    :'validity_day_of_week' => :'Array<Integer>',
    :'validity_hours' => :'ValidityHours',
    :'metadata' => :'Object',
    :'expiration_rules' => :'EarningRuleExpirationRules',
    :'validation_rule_id' => :'String',
    :'updated_at' => :'Time',
    :'active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created_at == o.created_at &&
      loyalty == o.loyalty &&
      event == o.event &&
      custom_event == o.custom_event &&
      segment == o.segment &&
      loyalty_tier == o.loyalty_tier &&
      pending_points == o.pending_points &&
      source == o.source &&
      object == o.object &&
      automation_id == o.automation_id &&
      start_date == o.start_date &&
      expiration_date == o.expiration_date &&
      validity_timeframe == o.validity_timeframe &&
      validity_day_of_week == o.validity_day_of_week &&
      validity_hours == o.validity_hours &&
       == o. &&
      expiration_rules == o.expiration_rules &&
      validation_rule_id == o.validation_rule_id &&
      updated_at == o.updated_at &&
      active == o.active
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 324

def hash
  [id, created_at, loyalty, event, custom_event, segment, loyalty_tier, pending_points, source, object, automation_id, start_date, expiration_date, validity_timeframe, validity_day_of_week, validity_hours, , expiration_rules, validation_rule_id, updated_at, active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



273
274
275
276
277
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 273

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



281
282
283
284
285
286
# File 'lib/VoucherifySdk/models/earning_rule.rb', line 281

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  object_validator = EnumAttributeValidator.new('String', ["earning_rule"])
  return false unless object_validator.valid?(@object)
  true
end