Class: VoucherifySdk::InapplicableTo

Inherits:
Object
  • Object
show all
Defined in:
lib/VoucherifySdk/models/inapplicable_to.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InapplicableTo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 266

def initialize(attributes = {})
  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    h[k.to_sym] = v
  }

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'source_id')
    self.source_id = attributes[:'source_id']
  end

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  end

  if attributes.key?(:'product_source_id')
    self.product_source_id = attributes[:'product_source_id']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'price_formula')
    self.price_formula = attributes[:'price_formula']
  end

  if attributes.key?(:'effect')
    self.effect = attributes[:'effect']
  else
    self.effect = nil
  end

  if attributes.key?(:'quantity_limit')
    self.quantity_limit = attributes[:'quantity_limit']
  end

  if attributes.key?(:'aggregated_quantity_limit')
    self.aggregated_quantity_limit = attributes[:'aggregated_quantity_limit']
  end

  if attributes.key?(:'amount_limit')
    self.amount_limit = attributes[:'amount_limit']
  end

  if attributes.key?(:'aggregated_amount_limit')
    self.aggregated_amount_limit = attributes[:'aggregated_amount_limit']
  end

  if attributes.key?(:'product_campaign_quantity_limit')
    self.product_campaign_quantity_limit = attributes[:'product_campaign_quantity_limit']
  end

  if attributes.key?(:'product_campaign_quantity_limit_formula')
    self.product_campaign_quantity_limit_formula = attributes[:'product_campaign_quantity_limit_formula']
  end

  if attributes.key?(:'product_customer_campaign_quantity_limit')
    self.product_customer_campaign_quantity_limit = attributes[:'product_customer_campaign_quantity_limit']
  end

  if attributes.key?(:'product_customer_campaign_quantity_limit_formula')
    self.product_customer_campaign_quantity_limit_formula = attributes[:'product_customer_campaign_quantity_limit_formula']
  end

  if attributes.key?(:'product_in_collection_campaign_quantity_limit')
    self.product_in_collection_campaign_quantity_limit = attributes[:'product_in_collection_campaign_quantity_limit']
  end

  if attributes.key?(:'product_in_collection_campaign_quantity_limit_formula')
    self.product_in_collection_campaign_quantity_limit_formula = attributes[:'product_in_collection_campaign_quantity_limit_formula']
  end

  if attributes.key?(:'product_in_collection_customer_campaign_quantity_limit')
    self.product_in_collection_customer_campaign_quantity_limit = attributes[:'product_in_collection_customer_campaign_quantity_limit']
  end

  if attributes.key?(:'product_in_collection_customer_campaign_quantity_limit_formula')
    self.product_in_collection_customer_campaign_quantity_limit_formula = attributes[:'product_in_collection_customer_campaign_quantity_limit_formula']
  end

  if attributes.key?(:'product_promotion_tier_quantity_limit')
    self.product_promotion_tier_quantity_limit = attributes[:'product_promotion_tier_quantity_limit']
  end

  if attributes.key?(:'product_promotion_tier_quantity_limit_formula')
    self.product_promotion_tier_quantity_limit_formula = attributes[:'product_promotion_tier_quantity_limit_formula']
  end

  if attributes.key?(:'product_customer_promotion_tier_quantity_limit')
    self.product_customer_promotion_tier_quantity_limit = attributes[:'product_customer_promotion_tier_quantity_limit']
  end

  if attributes.key?(:'product_customer_promotion_tier_quantity_limit_formula')
    self.product_customer_promotion_tier_quantity_limit_formula = attributes[:'product_customer_promotion_tier_quantity_limit_formula']
  end

  if attributes.key?(:'product_in_collection_promotion_tier_quantity_limit')
    self.product_in_collection_promotion_tier_quantity_limit = attributes[:'product_in_collection_promotion_tier_quantity_limit']
  end

  if attributes.key?(:'product_in_collection_promotion_tier_quantity_limit_formula')
    self.product_in_collection_promotion_tier_quantity_limit_formula = attributes[:'product_in_collection_promotion_tier_quantity_limit_formula']
  end

  if attributes.key?(:'product_in_collection_customer_promotion_tier_quantity_limit')
    self.product_in_collection_customer_promotion_tier_quantity_limit = attributes[:'product_in_collection_customer_promotion_tier_quantity_limit']
  end

  if attributes.key?(:'product_in_collection_customer_promotion_tier_quantity_limit_formula')
    self.product_in_collection_customer_promotion_tier_quantity_limit_formula = attributes[:'product_in_collection_customer_promotion_tier_quantity_limit_formula']
  end

  if attributes.key?(:'order_item_indices')
    if (value = attributes[:'order_item_indices']).is_a?(Array)
      self.order_item_indices = value
    end
  end

  if attributes.key?(:'order_item_units')
    if (value = attributes[:'order_item_units']).is_a?(Array)
      self.order_item_units = value
    end
  end

  if attributes.key?(:'repeat')
    self.repeat = attributes[:'repeat']
  end

  if attributes.key?(:'skip_initially')
    self.skip_initially = attributes[:'skip_initially']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'strict')
    self.strict = attributes[:'strict']
  end
end

Instance Attribute Details

#aggregated_amount_limitObject

Maximum discount amount per order. Value is multiplied by 100 to precisely represent 2 decimal places. For example, a $6 maximum discount on the entire order is written as 600. This value is definable for the following discount effects: - APPLY_TO_ITEMS (each item subtotal is discounted equally) - APPLY_TO_ITEMS_BY_QUANTITY (each unit of matched products has the same discount value)



51
52
53
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 51

def aggregated_amount_limit
  @aggregated_amount_limit
end

#aggregated_quantity_limitObject

The maximum number of units allowed to be discounted combined across all matched order line items.



45
46
47
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 45

def aggregated_quantity_limit
  @aggregated_quantity_limit
end

#amount_limitObject

Upper limit allowed to be applied as a discount per order line item. Value is multiplied by 100 to precisely represent 2 decimal places. For example, a $6 maximum discount is written as 600.



48
49
50
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 48

def amount_limit
  @amount_limit
end

#effectObject

Returns the value of attribute effect.



39
40
41
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 39

def effect
  @effect
end

#idObject

Unique product collection, product, or SKU identifier assigned by Voucherify.



22
23
24
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 22

def id
  @id
end

#objectObject

This object stores information about the resource to which the discount is applicable.



19
20
21
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 19

def object
  @object
end

#order_item_indicesObject

Lists which order lines are (not) covered by the discount. The order in the array is determined by the sequence of applied discounts, while the numbers correspond to the order lines sent in the order object in the request. The first order line is assigned 0, the second order line is assigned 1, and so on.



102
103
104
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 102

def order_item_indices
  @order_item_indices
end

#order_item_unitsObject

Lists which units within order lines are covered by the discount. The order line items are listed according to sequence of applied discounts while the index corresponds to the order line sent in the order object in the request.



105
106
107
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 105

def order_item_units
  @order_item_units
end

#priceObject

New fixed price of an item. Value is multiplied by 100 to precisely represent 2 decimal places. For example, a $10 price is written as 1000. In case of the fixed price being calculated by the formula, i.e. the price_formula parameter is present in the fixed price definition, this value becomes the fallback value. Such that in a case where the formula cannot be calculated due to missing metadata, for example, this value will be used as the fixed price.



34
35
36
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 34

def price
  @price
end

#price_formulaObject

Formula used to dynamically calculate the discounted price of an item.



37
38
39
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 37

def price_formula
  @price_formula
end

#product_campaign_quantity_limitObject

Limits the number of discounted item units (product, SKU, collection) that all customers can receive in a given campaign. If a product is selected, the limit covers all discounts across all SKUs belonging to that product. If a product collection is selected, the limit covers all products/SKUs within the collection. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



54
55
56
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 54

def product_campaign_quantity_limit
  @product_campaign_quantity_limit
end

#product_campaign_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per campaign. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



57
58
59
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 57

def product_campaign_quantity_limit_formula
  @product_campaign_quantity_limit_formula
end

#product_customer_campaign_quantity_limitObject

Limits the number of discounted item units (product, SKU, collection) that one customer can receive in a given campaign. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



60
61
62
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 60

def product_customer_campaign_quantity_limit
  @product_customer_campaign_quantity_limit
end

#product_customer_campaign_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per customer in a campaign. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



63
64
65
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 63

def product_customer_campaign_quantity_limit_formula
  @product_customer_campaign_quantity_limit_formula
end

#product_customer_promotion_tier_quantity_limitObject

Limits the number of discounted item units that one customer can receive in a given promotion tier. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



84
85
86
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 84

def product_customer_promotion_tier_quantity_limit
  @product_customer_promotion_tier_quantity_limit
end

#product_customer_promotion_tier_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per customer in a promotion tier. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



87
88
89
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 87

def product_customer_promotion_tier_quantity_limit_formula
  @product_customer_promotion_tier_quantity_limit_formula
end

#product_idObject

Parent product's unique ID assigned by Voucherify.



28
29
30
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 28

def product_id
  @product_id
end

#product_in_collection_campaign_quantity_limitObject

Limits the number of discounted item units of a given product in a collection that all customers can receive in a given campaign. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



66
67
68
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 66

def product_in_collection_campaign_quantity_limit
  @product_in_collection_campaign_quantity_limit
end

#product_in_collection_campaign_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per campaign for a product in a collection. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



69
70
71
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 69

def product_in_collection_campaign_quantity_limit_formula
  @product_in_collection_campaign_quantity_limit_formula
end

#product_in_collection_customer_campaign_quantity_limitObject

Limits the number of discounted item units of a given product in a collection that one customer can receive in a campaign. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



72
73
74
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 72

def product_in_collection_customer_campaign_quantity_limit
  @product_in_collection_customer_campaign_quantity_limit
end

#product_in_collection_customer_campaign_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per customer for a product in a collection. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



75
76
77
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 75

def product_in_collection_customer_campaign_quantity_limit_formula
  @product_in_collection_customer_campaign_quantity_limit_formula
end

#product_in_collection_customer_promotion_tier_quantity_limitObject

Limits the number of discounted item units of a given product in a collection that one customer can receive in a promotion tier. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



96
97
98
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 96

def product_in_collection_customer_promotion_tier_quantity_limit
  @product_in_collection_customer_promotion_tier_quantity_limit
end

#product_in_collection_customer_promotion_tier_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per customer in a promotion tier for a product in a collection. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



99
100
101
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 99

def product_in_collection_customer_promotion_tier_quantity_limit_formula
  @product_in_collection_customer_promotion_tier_quantity_limit_formula
end

#product_in_collection_promotion_tier_quantity_limitObject

Limits the number of discounted item units of a given product in a collection that all customers can receive in a given promotion tier. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



90
91
92
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 90

def product_in_collection_promotion_tier_quantity_limit
  @product_in_collection_promotion_tier_quantity_limit
end

#product_in_collection_promotion_tier_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per promotion tier for a product in a collection. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



93
94
95
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 93

def product_in_collection_promotion_tier_quantity_limit_formula
  @product_in_collection_promotion_tier_quantity_limit_formula
end

#product_promotion_tier_quantity_limitObject

Limits the number of discounted item units that all customers can receive in a promotion tier. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



78
79
80
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 78

def product_promotion_tier_quantity_limit
  @product_promotion_tier_quantity_limit
end

#product_promotion_tier_quantity_limit_formulaObject

Formula used to dynamically calculate the maximum units per promotion tier. This limit is available on demand as part of campaign budget limits. Contact Voucherify support or your account manager to learn more.



81
82
83
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 81

def product_promotion_tier_quantity_limit_formula
  @product_promotion_tier_quantity_limit_formula
end

#product_source_idObject

Parent product's source ID from your inventory system.



31
32
33
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 31

def product_source_id
  @product_source_id
end

#quantity_limitObject

The maximum number of units allowed to be discounted per order line item.



42
43
44
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 42

def quantity_limit
  @quantity_limit
end

#repeatObject

Determines the recurrence of the discount, e.g. \"repeat\": 3 means that the discount is applied to every third item.



108
109
110
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 108

def repeat
  @repeat
end

#skip_initiallyObject

Determines how many items are skipped before the discount is applied.



111
112
113
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 111

def skip_initially
  @skip_initially
end

#source_idObject

The source identifier from your inventory system.



25
26
27
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 25

def source_id
  @source_id
end

#strictObject

Returns the value of attribute strict.



116
117
118
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 116

def strict
  @strict
end

#targetObject

Determines to which kinds of objects the discount is applicable. ITEM includes products and SKUs. UNIT means particular units within an order line.



114
115
116
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 114

def target
  @target
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 517

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = VoucherifySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



181
182
183
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 181

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 141

def self.attribute_map
  {
    :'object' => :'object',
    :'id' => :'id',
    :'source_id' => :'source_id',
    :'product_id' => :'product_id',
    :'product_source_id' => :'product_source_id',
    :'price' => :'price',
    :'price_formula' => :'price_formula',
    :'effect' => :'effect',
    :'quantity_limit' => :'quantity_limit',
    :'aggregated_quantity_limit' => :'aggregated_quantity_limit',
    :'amount_limit' => :'amount_limit',
    :'aggregated_amount_limit' => :'aggregated_amount_limit',
    :'product_campaign_quantity_limit' => :'product_campaign_quantity_limit',
    :'product_campaign_quantity_limit_formula' => :'product_campaign_quantity_limit_formula',
    :'product_customer_campaign_quantity_limit' => :'product_customer_campaign_quantity_limit',
    :'product_customer_campaign_quantity_limit_formula' => :'product_customer_campaign_quantity_limit_formula',
    :'product_in_collection_campaign_quantity_limit' => :'product_in_collection_campaign_quantity_limit',
    :'product_in_collection_campaign_quantity_limit_formula' => :'product_in_collection_campaign_quantity_limit_formula',
    :'product_in_collection_customer_campaign_quantity_limit' => :'product_in_collection_customer_campaign_quantity_limit',
    :'product_in_collection_customer_campaign_quantity_limit_formula' => :'product_in_collection_customer_campaign_quantity_limit_formula',
    :'product_promotion_tier_quantity_limit' => :'product_promotion_tier_quantity_limit',
    :'product_promotion_tier_quantity_limit_formula' => :'product_promotion_tier_quantity_limit_formula',
    :'product_customer_promotion_tier_quantity_limit' => :'product_customer_promotion_tier_quantity_limit',
    :'product_customer_promotion_tier_quantity_limit_formula' => :'product_customer_promotion_tier_quantity_limit_formula',
    :'product_in_collection_promotion_tier_quantity_limit' => :'product_in_collection_promotion_tier_quantity_limit',
    :'product_in_collection_promotion_tier_quantity_limit_formula' => :'product_in_collection_promotion_tier_quantity_limit_formula',
    :'product_in_collection_customer_promotion_tier_quantity_limit' => :'product_in_collection_customer_promotion_tier_quantity_limit',
    :'product_in_collection_customer_promotion_tier_quantity_limit_formula' => :'product_in_collection_customer_promotion_tier_quantity_limit_formula',
    :'order_item_indices' => :'order_item_indices',
    :'order_item_units' => :'order_item_units',
    :'repeat' => :'repeat',
    :'skip_initially' => :'skip_initially',
    :'target' => :'target',
    :'strict' => :'strict'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 493

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 226

def self.openapi_nullable
  Set.new([
    :'object',
    :'id',
    :'source_id',
    :'product_id',
    :'product_source_id',
    :'price',
    :'price_formula',
    :'quantity_limit',
    :'aggregated_quantity_limit',
    :'amount_limit',
    :'aggregated_amount_limit',
    :'product_campaign_quantity_limit',
    :'product_campaign_quantity_limit_formula',
    :'product_customer_campaign_quantity_limit',
    :'product_customer_campaign_quantity_limit_formula',
    :'product_in_collection_campaign_quantity_limit',
    :'product_in_collection_campaign_quantity_limit_formula',
    :'product_in_collection_customer_campaign_quantity_limit',
    :'product_in_collection_customer_campaign_quantity_limit_formula',
    :'product_promotion_tier_quantity_limit',
    :'product_promotion_tier_quantity_limit_formula',
    :'product_customer_promotion_tier_quantity_limit',
    :'product_customer_promotion_tier_quantity_limit_formula',
    :'product_in_collection_promotion_tier_quantity_limit',
    :'product_in_collection_promotion_tier_quantity_limit_formula',
    :'product_in_collection_customer_promotion_tier_quantity_limit',
    :'product_in_collection_customer_promotion_tier_quantity_limit_formula',
    :'order_item_indices',
    :'order_item_units',
    :'repeat',
    :'skip_initially',
    :'target',
    :'strict'
  ])
end

.openapi_typesObject

Attribute type mapping.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 186

def self.openapi_types
  {
    :'object' => :'String',
    :'id' => :'String',
    :'source_id' => :'String',
    :'product_id' => :'String',
    :'product_source_id' => :'String',
    :'price' => :'Float',
    :'price_formula' => :'Float',
    :'effect' => :'ApplicableToEffect',
    :'quantity_limit' => :'Integer',
    :'aggregated_quantity_limit' => :'Integer',
    :'amount_limit' => :'Integer',
    :'aggregated_amount_limit' => :'Integer',
    :'product_campaign_quantity_limit' => :'Integer',
    :'product_campaign_quantity_limit_formula' => :'String',
    :'product_customer_campaign_quantity_limit' => :'Integer',
    :'product_customer_campaign_quantity_limit_formula' => :'String',
    :'product_in_collection_campaign_quantity_limit' => :'Integer',
    :'product_in_collection_campaign_quantity_limit_formula' => :'String',
    :'product_in_collection_customer_campaign_quantity_limit' => :'Integer',
    :'product_in_collection_customer_campaign_quantity_limit_formula' => :'String',
    :'product_promotion_tier_quantity_limit' => :'Integer',
    :'product_promotion_tier_quantity_limit_formula' => :'String',
    :'product_customer_promotion_tier_quantity_limit' => :'Integer',
    :'product_customer_promotion_tier_quantity_limit_formula' => :'String',
    :'product_in_collection_promotion_tier_quantity_limit' => :'Integer',
    :'product_in_collection_promotion_tier_quantity_limit_formula' => :'String',
    :'product_in_collection_customer_promotion_tier_quantity_limit' => :'Integer',
    :'product_in_collection_customer_promotion_tier_quantity_limit_formula' => :'String',
    :'order_item_indices' => :'Array<Integer>',
    :'order_item_units' => :'Array<InapplicableToOrderItemUnitsItem>',
    :'repeat' => :'Integer',
    :'skip_initially' => :'Integer',
    :'target' => :'String',
    :'strict' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 439

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object == o.object &&
      id == o.id &&
      source_id == o.source_id &&
      product_id == o.product_id &&
      product_source_id == o.product_source_id &&
      price == o.price &&
      price_formula == o.price_formula &&
      effect == o.effect &&
      quantity_limit == o.quantity_limit &&
      aggregated_quantity_limit == o.aggregated_quantity_limit &&
      amount_limit == o.amount_limit &&
      aggregated_amount_limit == o.aggregated_amount_limit &&
      product_campaign_quantity_limit == o.product_campaign_quantity_limit &&
      product_campaign_quantity_limit_formula == o.product_campaign_quantity_limit_formula &&
      product_customer_campaign_quantity_limit == o.product_customer_campaign_quantity_limit &&
      product_customer_campaign_quantity_limit_formula == o.product_customer_campaign_quantity_limit_formula &&
      product_in_collection_campaign_quantity_limit == o.product_in_collection_campaign_quantity_limit &&
      product_in_collection_campaign_quantity_limit_formula == o.product_in_collection_campaign_quantity_limit_formula &&
      product_in_collection_customer_campaign_quantity_limit == o.product_in_collection_customer_campaign_quantity_limit &&
      product_in_collection_customer_campaign_quantity_limit_formula == o.product_in_collection_customer_campaign_quantity_limit_formula &&
      product_promotion_tier_quantity_limit == o.product_promotion_tier_quantity_limit &&
      product_promotion_tier_quantity_limit_formula == o.product_promotion_tier_quantity_limit_formula &&
      product_customer_promotion_tier_quantity_limit == o.product_customer_promotion_tier_quantity_limit &&
      product_customer_promotion_tier_quantity_limit_formula == o.product_customer_promotion_tier_quantity_limit_formula &&
      product_in_collection_promotion_tier_quantity_limit == o.product_in_collection_promotion_tier_quantity_limit &&
      product_in_collection_promotion_tier_quantity_limit_formula == o.product_in_collection_promotion_tier_quantity_limit_formula &&
      product_in_collection_customer_promotion_tier_quantity_limit == o.product_in_collection_customer_promotion_tier_quantity_limit &&
      product_in_collection_customer_promotion_tier_quantity_limit_formula == o.product_in_collection_customer_promotion_tier_quantity_limit_formula &&
      order_item_indices == o.order_item_indices &&
      order_item_units == o.order_item_units &&
      repeat == o.repeat &&
      skip_initially == o.skip_initially &&
      target == o.target &&
      strict == o.strict
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 588

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


480
481
482
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 480

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



486
487
488
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 486

def hash
  [object, id, source_id, product_id, product_source_id, price, price_formula, effect, quantity_limit, aggregated_quantity_limit, amount_limit, aggregated_amount_limit, product_campaign_quantity_limit, product_campaign_quantity_limit_formula, product_customer_campaign_quantity_limit, product_customer_campaign_quantity_limit_formula, product_in_collection_campaign_quantity_limit, product_in_collection_campaign_quantity_limit_formula, product_in_collection_customer_campaign_quantity_limit, product_in_collection_customer_campaign_quantity_limit_formula, product_promotion_tier_quantity_limit, product_promotion_tier_quantity_limit_formula, product_customer_promotion_tier_quantity_limit, product_customer_promotion_tier_quantity_limit_formula, product_in_collection_promotion_tier_quantity_limit, product_in_collection_promotion_tier_quantity_limit_formula, product_in_collection_customer_promotion_tier_quantity_limit, product_in_collection_customer_promotion_tier_quantity_limit_formula, order_item_indices, order_item_units, repeat, skip_initially, target, strict].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



417
418
419
420
421
422
423
424
425
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 417

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @effect.nil?
    invalid_properties.push('invalid value for "effect", effect cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



564
565
566
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 564

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 570

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



558
559
560
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 558

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



429
430
431
432
433
434
435
# File 'lib/VoucherifySdk/models/inapplicable_to.rb', line 429

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  object_validator = EnumAttributeValidator.new('String', ["product", "sku", "products_collection"])
  return false unless object_validator.valid?(@object)
  return false if @effect.nil?
  true
end