Class: VoucherifySdk::ManagementProjectsStackingRulesCreateResponseBody
- Inherits:
-
Object
- Object
- VoucherifySdk::ManagementProjectsStackingRulesCreateResponseBody
- Defined in:
- lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb
Overview
Response body schema for POST /management/v1/projects/{projectId}/stacking-rules.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#applicable_exclusive_redeemables_limit ⇒ Object
Defines how many redeemables with an assigned exclusive category can be applied in one request.
-
#applicable_exclusive_redeemables_per_category_limit ⇒ Object
Defines how many redeemables with an assigned exclusive category can be applied in one request.
-
#applicable_redeemables_category_limits ⇒ Object
Lists categories by category IDs (keys) and defines their limits (values) of applicable redeemables that belong to campaigns with that category.
-
#applicable_redeemables_limit ⇒ Object
Defines how many redeemables can be applied in one request.
-
#applicable_redeemables_per_category_limit ⇒ Object
Defines how many redeemables with the same category can be applied in one request.
-
#created_at ⇒ Object
Timestamp representing the date and time when the stacking rules were created.
-
#discount_calculation_mode ⇒ Object
Defines if the discounts are applied by taking into account the initial order amount or the discounted order amount.
-
#discounted_amount_mode_categories ⇒ Object
Lists the IDs of the categories that apply a discount based on the discounted amount.
-
#exclusive_categories ⇒ Object
Lists the IDs of exclusive categories.
-
#id ⇒ Object
The unique identifier of the stacking rules.
-
#initial_amount_mode_categories ⇒ Object
Lists the IDs of the categories that apply a discount based on the initial amount.
-
#joint_categories ⇒ Object
Lists the IDs of the joint categories.
-
#no_effect_redeem_anyway_categories ⇒ Object
Lists category IDs.
-
#no_effect_skip_categories ⇒ Object
Lists category IDs.
-
#redeemables_application_mode ⇒ Object
Defines the application mode for redeemables.
-
#redeemables_limit ⇒ Object
Defines how many redeemables can be sent in one request.
-
#redeemables_no_effect_rule ⇒ Object
Defines redeemables no effect rule.
-
#redeemables_products_application_mode ⇒ Object
Defines redeemables products application mode.
-
#redeemables_rollback_order_mode ⇒ Object
Defines the rollback mode for the order.
-
#redeemables_sorting_rule ⇒ Object
Defines redeemables sorting rule.
-
#updated_at ⇒ Object
Timestamp representing the date and time when the stacking rules were updated.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementProjectsStackingRulesCreateResponseBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementProjectsStackingRulesCreateResponseBody
Initializes the object
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 192 def initialize(attributes = {}) # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'exclusive_categories') if (value = attributes[:'exclusive_categories']).is_a?(Array) self.exclusive_categories = value end end if attributes.key?(:'joint_categories') if (value = attributes[:'joint_categories']).is_a?(Array) self.joint_categories = value end end if attributes.key?(:'redeemables_limit') self.redeemables_limit = attributes[:'redeemables_limit'] end if attributes.key?(:'applicable_redeemables_limit') self.applicable_redeemables_limit = attributes[:'applicable_redeemables_limit'] end if attributes.key?(:'applicable_redeemables_per_category_limit') self.applicable_redeemables_per_category_limit = attributes[:'applicable_redeemables_per_category_limit'] end if attributes.key?(:'applicable_redeemables_category_limits') if (value = attributes[:'applicable_redeemables_category_limits']).is_a?(Hash) self.applicable_redeemables_category_limits = value end end if attributes.key?(:'applicable_exclusive_redeemables_limit') self.applicable_exclusive_redeemables_limit = attributes[:'applicable_exclusive_redeemables_limit'] end if attributes.key?(:'applicable_exclusive_redeemables_per_category_limit') self.applicable_exclusive_redeemables_per_category_limit = attributes[:'applicable_exclusive_redeemables_per_category_limit'] end if attributes.key?(:'discount_calculation_mode') self.discount_calculation_mode = attributes[:'discount_calculation_mode'] end if attributes.key?(:'initial_amount_mode_categories') if (value = attributes[:'initial_amount_mode_categories']).is_a?(Array) self.initial_amount_mode_categories = value end end if attributes.key?(:'discounted_amount_mode_categories') if (value = attributes[:'discounted_amount_mode_categories']).is_a?(Array) self.discounted_amount_mode_categories = value end end if attributes.key?(:'redeemables_application_mode') self.redeemables_application_mode = attributes[:'redeemables_application_mode'] end if attributes.key?(:'redeemables_sorting_rule') self.redeemables_sorting_rule = attributes[:'redeemables_sorting_rule'] end if attributes.key?(:'redeemables_products_application_mode') self.redeemables_products_application_mode = attributes[:'redeemables_products_application_mode'] end if attributes.key?(:'redeemables_no_effect_rule') self.redeemables_no_effect_rule = attributes[:'redeemables_no_effect_rule'] end if attributes.key?(:'no_effect_skip_categories') if (value = attributes[:'no_effect_skip_categories']).is_a?(Array) self.no_effect_skip_categories = value end end if attributes.key?(:'no_effect_redeem_anyway_categories') if (value = attributes[:'no_effect_redeem_anyway_categories']).is_a?(Array) self.no_effect_redeem_anyway_categories = value end end if attributes.key?(:'redeemables_rollback_order_mode') self.redeemables_rollback_order_mode = attributes[:'redeemables_rollback_order_mode'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#applicable_exclusive_redeemables_limit ⇒ Object
Defines how many redeemables with an assigned exclusive category can be applied in one request. The ones above the limit will be SKIPPED according to the redeemables_sorting_rule.
41 42 43 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 41 def applicable_exclusive_redeemables_limit @applicable_exclusive_redeemables_limit end |
#applicable_exclusive_redeemables_per_category_limit ⇒ Object
Defines how many redeemables with an assigned exclusive category can be applied in one request. The ones above the limit will be SKIPPED according to the redeemables_sorting_rule. The number must be less than or equal to applicable_exclusive_redeemables_limit.
44 45 46 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 44 def applicable_exclusive_redeemables_per_category_limit @applicable_exclusive_redeemables_per_category_limit end |
#applicable_redeemables_category_limits ⇒ Object
Lists categories by category IDs (keys) and defines their limits (values) of applicable redeemables that belong to campaigns with that category.
38 39 40 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 38 def applicable_redeemables_category_limits @applicable_redeemables_category_limits end |
#applicable_redeemables_limit ⇒ Object
Defines how many redeemables can be applied in one request. The number must be less than or equal to redeemables_limit. For example, a user can select 30 discounts but only 5 will be applied to the order and the remaining will be SKIPPED according to the redeemables_sorting_rule.
32 33 34 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 32 def applicable_redeemables_limit @applicable_redeemables_limit end |
#applicable_redeemables_per_category_limit ⇒ Object
Defines how many redeemables with the same category can be applied in one request. The number must be less than or equal to applicable_redeemables_limit. The ones above the limit will be SKIPPED according to the redeemables_sorting_rule.
35 36 37 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 35 def applicable_redeemables_per_category_limit @applicable_redeemables_per_category_limit end |
#created_at ⇒ Object
Timestamp representing the date and time when the stacking rules were created. The value for this parameter is shown in the ISO 8601 format.
77 78 79 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 77 def created_at @created_at end |
#discount_calculation_mode ⇒ Object
Defines if the discounts are applied by taking into account the initial order amount or the discounted order amount.
47 48 49 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 47 def discount_calculation_mode @discount_calculation_mode end |
#discounted_amount_mode_categories ⇒ Object
Lists the IDs of the categories that apply a discount based on the discounted amount.
53 54 55 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 53 def discounted_amount_mode_categories @discounted_amount_mode_categories end |
#exclusive_categories ⇒ Object
Lists the IDs of exclusive categories. A redeemable from a campaign with an exclusive category is the only redeemable to be redeemed when applied with redeemables from other campaigns unless these campaigns are exclusive or joint.
23 24 25 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 23 def exclusive_categories @exclusive_categories end |
#id ⇒ Object
The unique identifier of the stacking rules.
20 21 22 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 20 def id @id end |
#initial_amount_mode_categories ⇒ Object
Lists the IDs of the categories that apply a discount based on the initial amount.
50 51 52 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 50 def initial_amount_mode_categories @initial_amount_mode_categories end |
#joint_categories ⇒ Object
Lists the IDs of the joint categories. A campaign with a joint category is always applied regardless of the exclusivity of other campaigns.
26 27 28 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 26 def joint_categories @joint_categories end |
#no_effect_redeem_anyway_categories ⇒ Object
Lists category IDs. Redeemables with a given category are redeemed anyway even if the redeemables_no_effect_rule is set to SKIP. Category IDs can't overlap with the IDs in no_effect_skip_categories.
71 72 73 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 71 def no_effect_redeem_anyway_categories @no_effect_redeem_anyway_categories end |
#no_effect_skip_categories ⇒ Object
Lists category IDs. Redeemables with a given category are skipped even if the redeemables_no_effect_rule is set to REDEEM_ANYWAY. Category IDs can't overlap with the IDs in no_effect_redeem_anyway_categories.
68 69 70 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 68 def no_effect_skip_categories @no_effect_skip_categories end |
#redeemables_application_mode ⇒ Object
Defines the application mode for redeemables. \"ALL\" means that all redeemables must be validated for the redemption to be successful. \"PARTIAL\" means that only those redeemables that can be validated will be redeemed. The redeemables that fail validaton will be skipped.
56 57 58 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 56 def redeemables_application_mode @redeemables_application_mode end |
#redeemables_limit ⇒ Object
Defines how many redeemables can be sent in one request. Note: more redeemables means more processing time.
29 30 31 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 29 def redeemables_limit @redeemables_limit end |
#redeemables_no_effect_rule ⇒ Object
Defines redeemables no effect rule. REDEEM_ANYWAY means that the redeemable will be redeemed regardless of any restrictions or conditions in place. SKIP means that the redeemable will be processed only when an applicable effect is calculated.
65 66 67 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 65 def redeemables_no_effect_rule @redeemables_no_effect_rule end |
#redeemables_products_application_mode ⇒ Object
Defines redeemables products application mode. STACK means that multiple discounts can be applied to a product. ONCE means that only one discount can be applied to the same product.
62 63 64 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 62 def redeemables_products_application_mode @redeemables_products_application_mode end |
#redeemables_rollback_order_mode ⇒ Object
Defines the rollback mode for the order. WITH_ORDER is a default setting. The redemption is rolled back together with the data about the order, including related discount values. WITHOUT_ORDER allows rolling the redemption back without affecting order data, including the applied discount values.
74 75 76 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 74 def redeemables_rollback_order_mode @redeemables_rollback_order_mode end |
#redeemables_sorting_rule ⇒ Object
Defines redeemables sorting rule. CATEGORY_HIERARCHY means that redeemables are applied oaccording to the category priority. REQUESTED_ORDER means that redeemables are applied in the sequence provided in the request.
59 60 61 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 59 def redeemables_sorting_rule @redeemables_sorting_rule end |
#updated_at ⇒ Object
Timestamp representing the date and time when the stacking rules were updated. The value for this parameter is shown in the ISO 8601 format.
80 81 82 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 80 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 441 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = VoucherifySdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
132 133 134 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 132 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 105 def self.attribute_map { :'id' => :'id', :'exclusive_categories' => :'exclusive_categories', :'joint_categories' => :'joint_categories', :'redeemables_limit' => :'redeemables_limit', :'applicable_redeemables_limit' => :'applicable_redeemables_limit', :'applicable_redeemables_per_category_limit' => :'applicable_redeemables_per_category_limit', :'applicable_redeemables_category_limits' => :'applicable_redeemables_category_limits', :'applicable_exclusive_redeemables_limit' => :'applicable_exclusive_redeemables_limit', :'applicable_exclusive_redeemables_per_category_limit' => :'applicable_exclusive_redeemables_per_category_limit', :'discount_calculation_mode' => :'discount_calculation_mode', :'initial_amount_mode_categories' => :'initial_amount_mode_categories', :'discounted_amount_mode_categories' => :'discounted_amount_mode_categories', :'redeemables_application_mode' => :'redeemables_application_mode', :'redeemables_sorting_rule' => :'redeemables_sorting_rule', :'redeemables_products_application_mode' => :'redeemables_products_application_mode', :'redeemables_no_effect_rule' => :'redeemables_no_effect_rule', :'no_effect_skip_categories' => :'no_effect_skip_categories', :'no_effect_redeem_anyway_categories' => :'no_effect_redeem_anyway_categories', :'redeemables_rollback_order_mode' => :'redeemables_rollback_order_mode', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 417 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 164 def self.openapi_nullable Set.new([ :'id', :'exclusive_categories', :'joint_categories', :'redeemables_limit', :'applicable_redeemables_limit', :'applicable_redeemables_per_category_limit', :'applicable_redeemables_category_limits', :'applicable_exclusive_redeemables_limit', :'applicable_exclusive_redeemables_per_category_limit', :'discount_calculation_mode', :'initial_amount_mode_categories', :'discounted_amount_mode_categories', :'redeemables_application_mode', :'redeemables_sorting_rule', :'redeemables_products_application_mode', :'redeemables_no_effect_rule', :'no_effect_skip_categories', :'no_effect_redeem_anyway_categories', :'redeemables_rollback_order_mode', :'created_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 137 def self.openapi_types { :'id' => :'String', :'exclusive_categories' => :'Array<String>', :'joint_categories' => :'Array<String>', :'redeemables_limit' => :'Integer', :'applicable_redeemables_limit' => :'Integer', :'applicable_redeemables_per_category_limit' => :'Integer', :'applicable_redeemables_category_limits' => :'Hash<String, Integer>', :'applicable_exclusive_redeemables_limit' => :'Integer', :'applicable_exclusive_redeemables_per_category_limit' => :'Integer', :'discount_calculation_mode' => :'String', :'initial_amount_mode_categories' => :'Array<String>', :'discounted_amount_mode_categories' => :'Array<String>', :'redeemables_application_mode' => :'String', :'redeemables_sorting_rule' => :'String', :'redeemables_products_application_mode' => :'String', :'redeemables_no_effect_rule' => :'String', :'no_effect_skip_categories' => :'Array<String>', :'no_effect_redeem_anyway_categories' => :'Array<String>', :'redeemables_rollback_order_mode' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 376 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && exclusive_categories == o.exclusive_categories && joint_categories == o.joint_categories && redeemables_limit == o.redeemables_limit && applicable_redeemables_limit == o.applicable_redeemables_limit && applicable_redeemables_per_category_limit == o.applicable_redeemables_per_category_limit && applicable_redeemables_category_limits == o.applicable_redeemables_category_limits && applicable_exclusive_redeemables_limit == o.applicable_exclusive_redeemables_limit && applicable_exclusive_redeemables_per_category_limit == o.applicable_exclusive_redeemables_per_category_limit && discount_calculation_mode == o.discount_calculation_mode && initial_amount_mode_categories == o.initial_amount_mode_categories && discounted_amount_mode_categories == o.discounted_amount_mode_categories && redeemables_application_mode == o.redeemables_application_mode && redeemables_sorting_rule == o.redeemables_sorting_rule && redeemables_products_application_mode == o.redeemables_products_application_mode && redeemables_no_effect_rule == o.redeemables_no_effect_rule && no_effect_skip_categories == o.no_effect_skip_categories && no_effect_redeem_anyway_categories == o.no_effect_redeem_anyway_categories && redeemables_rollback_order_mode == o.redeemables_rollback_order_mode && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
512 513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 512 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
404 405 406 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 404 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
410 411 412 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 410 def hash [id, exclusive_categories, joint_categories, redeemables_limit, applicable_redeemables_limit, applicable_redeemables_per_category_limit, applicable_redeemables_category_limits, applicable_exclusive_redeemables_limit, applicable_exclusive_redeemables_per_category_limit, discount_calculation_mode, initial_amount_mode_categories, discounted_amount_mode_categories, redeemables_application_mode, redeemables_sorting_rule, redeemables_products_application_mode, redeemables_no_effect_rule, no_effect_skip_categories, no_effect_redeem_anyway_categories, redeemables_rollback_order_mode, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 299 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@redeemables_limit.nil? && @redeemables_limit > 30 invalid_properties.push('invalid value for "redeemables_limit", must be smaller than or equal to 30.') end if !@redeemables_limit.nil? && @redeemables_limit < 1 invalid_properties.push('invalid value for "redeemables_limit", must be greater than or equal to 1.') end if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit > 30 invalid_properties.push('invalid value for "applicable_redeemables_limit", must be smaller than or equal to 30.') end if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit < 1 invalid_properties.push('invalid value for "applicable_redeemables_limit", must be greater than or equal to 1.') end if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit > 30 invalid_properties.push('invalid value for "applicable_redeemables_per_category_limit", must be smaller than or equal to 30.') end if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit < 1 invalid_properties.push('invalid value for "applicable_redeemables_per_category_limit", must be greater than or equal to 1.') end if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit > 5 invalid_properties.push('invalid value for "applicable_exclusive_redeemables_limit", must be smaller than or equal to 5.') end if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit < 1 invalid_properties.push('invalid value for "applicable_exclusive_redeemables_limit", must be greater than or equal to 1.') end if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit > 30 invalid_properties.push('invalid value for "applicable_exclusive_redeemables_per_category_limit", must be smaller than or equal to 30.') end if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit < 1 invalid_properties.push('invalid value for "applicable_exclusive_redeemables_per_category_limit", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
488 489 490 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 488 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 494 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
482 483 484 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 482 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_create_response_body.rb', line 347 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@redeemables_limit.nil? && @redeemables_limit > 30 return false if !@redeemables_limit.nil? && @redeemables_limit < 1 return false if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit > 30 return false if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit < 1 return false if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit > 30 return false if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit < 1 return false if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit > 5 return false if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit < 1 return false if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit > 30 return false if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit < 1 discount_calculation_mode_validator = EnumAttributeValidator.new('String', ["INITIAL_AMOUNT", "DISCOUNTED_AMOUNT"]) return false unless discount_calculation_mode_validator.valid?(@discount_calculation_mode) redeemables_application_mode_validator = EnumAttributeValidator.new('String', ["ALL", "PARTIAL"]) return false unless redeemables_application_mode_validator.valid?(@redeemables_application_mode) redeemables_sorting_rule_validator = EnumAttributeValidator.new('String', ["CATEGORY_HIERARCHY", "REQUESTED_ORDER"]) return false unless redeemables_sorting_rule_validator.valid?(@redeemables_sorting_rule) redeemables_products_application_mode_validator = EnumAttributeValidator.new('String', ["STACK", "ONCE"]) return false unless redeemables_products_application_mode_validator.valid?(@redeemables_products_application_mode) redeemables_no_effect_rule_validator = EnumAttributeValidator.new('String', ["REDEEM_ANYWAY", "SKIP"]) return false unless redeemables_no_effect_rule_validator.valid?(@redeemables_no_effect_rule) redeemables_rollback_order_mode_validator = EnumAttributeValidator.new('String', ["WITH_ORDER", "WITHOUT_ORDER"]) return false unless redeemables_rollback_order_mode_validator.valid?(@redeemables_rollback_order_mode) true end |