Class: VoucherifySdk::ManagementProjectsStackingRulesUpdateRequestBody

Inherits:
Object
  • Object
show all
Defined in:
lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb

Overview

Request body schema for PUT /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId}.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManagementProjectsStackingRulesUpdateRequestBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 174

def initialize(attributes = {})
  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    h[k.to_sym] = v
  }

  if attributes.key?(:'exclusive_categories')
    if (value = attributes[:'exclusive_categories']).is_a?(Array)
      self.exclusive_categories = value
    end
  end

  if attributes.key?(:'joint_categories')
    if (value = attributes[:'joint_categories']).is_a?(Array)
      self.joint_categories = value
    end
  end

  if attributes.key?(:'redeemables_limit')
    self.redeemables_limit = attributes[:'redeemables_limit']
  end

  if attributes.key?(:'applicable_redeemables_limit')
    self.applicable_redeemables_limit = attributes[:'applicable_redeemables_limit']
  end

  if attributes.key?(:'applicable_redeemables_per_category_limit')
    self.applicable_redeemables_per_category_limit = attributes[:'applicable_redeemables_per_category_limit']
  end

  if attributes.key?(:'applicable_redeemables_category_limits')
    if (value = attributes[:'applicable_redeemables_category_limits']).is_a?(Hash)
      self.applicable_redeemables_category_limits = value
    end
  end

  if attributes.key?(:'applicable_exclusive_redeemables_limit')
    self.applicable_exclusive_redeemables_limit = attributes[:'applicable_exclusive_redeemables_limit']
  end

  if attributes.key?(:'applicable_exclusive_redeemables_per_category_limit')
    self.applicable_exclusive_redeemables_per_category_limit = attributes[:'applicable_exclusive_redeemables_per_category_limit']
  end

  if attributes.key?(:'discount_calculation_mode')
    self.discount_calculation_mode = attributes[:'discount_calculation_mode']
  end

  if attributes.key?(:'initial_amount_mode_categories')
    if (value = attributes[:'initial_amount_mode_categories']).is_a?(Array)
      self.initial_amount_mode_categories = value
    end
  end

  if attributes.key?(:'discounted_amount_mode_categories')
    if (value = attributes[:'discounted_amount_mode_categories']).is_a?(Array)
      self.discounted_amount_mode_categories = value
    end
  end

  if attributes.key?(:'redeemables_application_mode')
    self.redeemables_application_mode = attributes[:'redeemables_application_mode']
  end

  if attributes.key?(:'redeemables_sorting_rule')
    self.redeemables_sorting_rule = attributes[:'redeemables_sorting_rule']
  end

  if attributes.key?(:'redeemables_products_application_mode')
    self.redeemables_products_application_mode = attributes[:'redeemables_products_application_mode']
  end

  if attributes.key?(:'redeemables_no_effect_rule')
    self.redeemables_no_effect_rule = attributes[:'redeemables_no_effect_rule']
  end

  if attributes.key?(:'no_effect_skip_categories')
    if (value = attributes[:'no_effect_skip_categories']).is_a?(Array)
      self.no_effect_skip_categories = value
    end
  end

  if attributes.key?(:'no_effect_redeem_anyway_categories')
    if (value = attributes[:'no_effect_redeem_anyway_categories']).is_a?(Array)
      self.no_effect_redeem_anyway_categories = value
    end
  end

  if attributes.key?(:'redeemables_rollback_order_mode')
    self.redeemables_rollback_order_mode = attributes[:'redeemables_rollback_order_mode']
  end
end

Instance Attribute Details

#applicable_exclusive_redeemables_limitObject

Defines how many redeemables with an assigned exclusive category can be applied in one request. The ones above the limit will be SKIPPED according to the redeemables_sorting_rule.



38
39
40
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 38

def applicable_exclusive_redeemables_limit
  @applicable_exclusive_redeemables_limit
end

#applicable_exclusive_redeemables_per_category_limitObject

Defines how many redeemables with an assigned exclusive category can be applied in one request. The ones above the limit will be SKIPPED according to the redeemables_sorting_rule. The number must be less than or equal to applicable_exclusive_redeemables_limit.



41
42
43
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 41

def applicable_exclusive_redeemables_per_category_limit
  @applicable_exclusive_redeemables_per_category_limit
end

#applicable_redeemables_category_limitsObject

Lists categories by category IDs (keys) and defines their limits (values) of applicable redeemables that belong to campaigns with that category.



35
36
37
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 35

def applicable_redeemables_category_limits
  @applicable_redeemables_category_limits
end

#applicable_redeemables_limitObject

Defines how many redeemables can be applied in one request. The number must be less than or equal to redeemables_limit. For example, a user can select 30 discounts but only 5 will be applied to the order and the remaining will be SKIPPED according to the redeemables_sorting_rule.



29
30
31
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 29

def applicable_redeemables_limit
  @applicable_redeemables_limit
end

#applicable_redeemables_per_category_limitObject

Defines how many redeemables with the same category can be applied in one request. The number must be less than or equal to applicable_redeemables_limit. The ones above the limit will be SKIPPED according to the redeemables_sorting_rule.



32
33
34
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 32

def applicable_redeemables_per_category_limit
  @applicable_redeemables_per_category_limit
end

#discount_calculation_modeObject

Defines if the discounts are applied by taking into account the initial order amount or the discounted order amount.



44
45
46
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 44

def discount_calculation_mode
  @discount_calculation_mode
end

#discounted_amount_mode_categoriesObject

Lists the IDs of the categories that apply a discount based on the discounted amount.



50
51
52
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 50

def discounted_amount_mode_categories
  @discounted_amount_mode_categories
end

#exclusive_categoriesObject

Lists the IDs of exclusive categories. A redeemable from a campaign with an exclusive category is the only redeemable to be redeemed when applied with redeemables from other campaigns unless these campaigns are exclusive or joint.



20
21
22
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 20

def exclusive_categories
  @exclusive_categories
end

#initial_amount_mode_categoriesObject

Lists the IDs of the categories that apply a discount based on the initial amount.



47
48
49
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 47

def initial_amount_mode_categories
  @initial_amount_mode_categories
end

#joint_categoriesObject

Lists the IDs of the joint categories. A campaign with a joint category is always applied regardless of the exclusivity of other campaigns.



23
24
25
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 23

def joint_categories
  @joint_categories
end

#no_effect_redeem_anyway_categoriesObject

Lists category IDs. Redeemables with a given category are redeemed anyway even if the redeemables_no_effect_rule is set to SKIP. Category IDs can't overlap with the IDs in no_effect_skip_categories.



68
69
70
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 68

def no_effect_redeem_anyway_categories
  @no_effect_redeem_anyway_categories
end

#no_effect_skip_categoriesObject

Lists category IDs. Redeemables with a given category are skipped even if the redeemables_no_effect_rule is set to REDEEM_ANYWAY. Category IDs can't overlap with the IDs in no_effect_redeem_anyway_categories.



65
66
67
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 65

def no_effect_skip_categories
  @no_effect_skip_categories
end

#redeemables_application_modeObject

Defines the application mode for redeemables. \"ALL\" means that all redeemables must be validated for the redemption to be successful. \"PARTIAL\" means that only those redeemables that can be validated will be redeemed. The redeemables that fail validaton will be skipped.



53
54
55
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 53

def redeemables_application_mode
  @redeemables_application_mode
end

#redeemables_limitObject

Defines how many redeemables can be sent in one request. Note: more redeemables means more processing time.



26
27
28
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 26

def redeemables_limit
  @redeemables_limit
end

#redeemables_no_effect_ruleObject

Defines redeemables no effect rule. REDEEM_ANYWAY means that the redeemable will be redeemed regardless of any restrictions or conditions in place. SKIP means that the redeemable will be processed only when an applicable effect is calculated.



62
63
64
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 62

def redeemables_no_effect_rule
  @redeemables_no_effect_rule
end

#redeemables_products_application_modeObject

Defines redeemables products application mode. STACK means that multiple discounts can be applied to a product. ONCE means that only one discount can be applied to the same product.



59
60
61
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 59

def redeemables_products_application_mode
  @redeemables_products_application_mode
end

#redeemables_rollback_order_modeObject

Defines the rollback mode for the order. WITH_ORDER is a default setting. The redemption is rolled back together with the data about the order, including related discount values. WITHOUT_ORDER allows rolling the redemption back without affecting order data, including the applied discount values.



71
72
73
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 71

def redeemables_rollback_order_mode
  @redeemables_rollback_order_mode
end

#redeemables_sorting_ruleObject

Defines redeemables sorting rule. CATEGORY_HIERARCHY means that redeemables are applied oaccording to the category priority. REQUESTED_ORDER means that redeemables are applied in the sequence provided in the request.



56
57
58
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 56

def redeemables_sorting_rule
  @redeemables_sorting_rule
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 408

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = VoucherifySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 120

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 96

def self.attribute_map
  {
    :'exclusive_categories' => :'exclusive_categories',
    :'joint_categories' => :'joint_categories',
    :'redeemables_limit' => :'redeemables_limit',
    :'applicable_redeemables_limit' => :'applicable_redeemables_limit',
    :'applicable_redeemables_per_category_limit' => :'applicable_redeemables_per_category_limit',
    :'applicable_redeemables_category_limits' => :'applicable_redeemables_category_limits',
    :'applicable_exclusive_redeemables_limit' => :'applicable_exclusive_redeemables_limit',
    :'applicable_exclusive_redeemables_per_category_limit' => :'applicable_exclusive_redeemables_per_category_limit',
    :'discount_calculation_mode' => :'discount_calculation_mode',
    :'initial_amount_mode_categories' => :'initial_amount_mode_categories',
    :'discounted_amount_mode_categories' => :'discounted_amount_mode_categories',
    :'redeemables_application_mode' => :'redeemables_application_mode',
    :'redeemables_sorting_rule' => :'redeemables_sorting_rule',
    :'redeemables_products_application_mode' => :'redeemables_products_application_mode',
    :'redeemables_no_effect_rule' => :'redeemables_no_effect_rule',
    :'no_effect_skip_categories' => :'no_effect_skip_categories',
    :'no_effect_redeem_anyway_categories' => :'no_effect_redeem_anyway_categories',
    :'redeemables_rollback_order_mode' => :'redeemables_rollback_order_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 384

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 149

def self.openapi_nullable
  Set.new([
    :'exclusive_categories',
    :'joint_categories',
    :'redeemables_limit',
    :'applicable_redeemables_limit',
    :'applicable_redeemables_per_category_limit',
    :'applicable_redeemables_category_limits',
    :'applicable_exclusive_redeemables_limit',
    :'applicable_exclusive_redeemables_per_category_limit',
    :'discount_calculation_mode',
    :'initial_amount_mode_categories',
    :'discounted_amount_mode_categories',
    :'redeemables_application_mode',
    :'redeemables_sorting_rule',
    :'redeemables_products_application_mode',
    :'redeemables_no_effect_rule',
    :'no_effect_skip_categories',
    :'no_effect_redeem_anyway_categories',
    :'redeemables_rollback_order_mode'
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 125

def self.openapi_types
  {
    :'exclusive_categories' => :'Array<String>',
    :'joint_categories' => :'Array<String>',
    :'redeemables_limit' => :'Integer',
    :'applicable_redeemables_limit' => :'Integer',
    :'applicable_redeemables_per_category_limit' => :'Integer',
    :'applicable_redeemables_category_limits' => :'Hash<String, Integer>',
    :'applicable_exclusive_redeemables_limit' => :'Integer',
    :'applicable_exclusive_redeemables_per_category_limit' => :'Integer',
    :'discount_calculation_mode' => :'String',
    :'initial_amount_mode_categories' => :'Array<String>',
    :'discounted_amount_mode_categories' => :'Array<String>',
    :'redeemables_application_mode' => :'String',
    :'redeemables_sorting_rule' => :'String',
    :'redeemables_products_application_mode' => :'String',
    :'redeemables_no_effect_rule' => :'String',
    :'no_effect_skip_categories' => :'Array<String>',
    :'no_effect_redeem_anyway_categories' => :'Array<String>',
    :'redeemables_rollback_order_mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      exclusive_categories == o.exclusive_categories &&
      joint_categories == o.joint_categories &&
      redeemables_limit == o.redeemables_limit &&
      applicable_redeemables_limit == o.applicable_redeemables_limit &&
      applicable_redeemables_per_category_limit == o.applicable_redeemables_per_category_limit &&
      applicable_redeemables_category_limits == o.applicable_redeemables_category_limits &&
      applicable_exclusive_redeemables_limit == o.applicable_exclusive_redeemables_limit &&
      applicable_exclusive_redeemables_per_category_limit == o.applicable_exclusive_redeemables_per_category_limit &&
      discount_calculation_mode == o.discount_calculation_mode &&
      initial_amount_mode_categories == o.initial_amount_mode_categories &&
      discounted_amount_mode_categories == o.discounted_amount_mode_categories &&
      redeemables_application_mode == o.redeemables_application_mode &&
      redeemables_sorting_rule == o.redeemables_sorting_rule &&
      redeemables_products_application_mode == o.redeemables_products_application_mode &&
      redeemables_no_effect_rule == o.redeemables_no_effect_rule &&
      no_effect_skip_categories == o.no_effect_skip_categories &&
      no_effect_redeem_anyway_categories == o.no_effect_redeem_anyway_categories &&
      redeemables_rollback_order_mode == o.redeemables_rollback_order_mode
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 479

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


371
372
373
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 371

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



377
378
379
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 377

def hash
  [exclusive_categories, joint_categories, redeemables_limit, applicable_redeemables_limit, applicable_redeemables_per_category_limit, applicable_redeemables_category_limits, applicable_exclusive_redeemables_limit, applicable_exclusive_redeemables_per_category_limit, discount_calculation_mode, initial_amount_mode_categories, discounted_amount_mode_categories, redeemables_application_mode, redeemables_sorting_rule, redeemables_products_application_mode, redeemables_no_effect_rule, no_effect_skip_categories, no_effect_redeem_anyway_categories, redeemables_rollback_order_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 269

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@redeemables_limit.nil? && @redeemables_limit > 30
    invalid_properties.push('invalid value for "redeemables_limit", must be smaller than or equal to 30.')
  end

  if !@redeemables_limit.nil? && @redeemables_limit < 1
    invalid_properties.push('invalid value for "redeemables_limit", must be greater than or equal to 1.')
  end

  if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit > 30
    invalid_properties.push('invalid value for "applicable_redeemables_limit", must be smaller than or equal to 30.')
  end

  if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit < 1
    invalid_properties.push('invalid value for "applicable_redeemables_limit", must be greater than or equal to 1.')
  end

  if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit > 30
    invalid_properties.push('invalid value for "applicable_redeemables_per_category_limit", must be smaller than or equal to 30.')
  end

  if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit < 1
    invalid_properties.push('invalid value for "applicable_redeemables_per_category_limit", must be greater than or equal to 1.')
  end

  if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit > 5
    invalid_properties.push('invalid value for "applicable_exclusive_redeemables_limit", must be smaller than or equal to 5.')
  end

  if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit < 1
    invalid_properties.push('invalid value for "applicable_exclusive_redeemables_limit", must be greater than or equal to 1.')
  end

  if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit > 30
    invalid_properties.push('invalid value for "applicable_exclusive_redeemables_per_category_limit", must be smaller than or equal to 30.')
  end

  if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit < 1
    invalid_properties.push('invalid value for "applicable_exclusive_redeemables_per_category_limit", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



455
456
457
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 455

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 461

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



449
450
451
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 449

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/VoucherifySdk/models/management_projects_stacking_rules_update_request_body.rb', line 317

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@redeemables_limit.nil? && @redeemables_limit > 30
  return false if !@redeemables_limit.nil? && @redeemables_limit < 1
  return false if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit > 30
  return false if !@applicable_redeemables_limit.nil? && @applicable_redeemables_limit < 1
  return false if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit > 30
  return false if !@applicable_redeemables_per_category_limit.nil? && @applicable_redeemables_per_category_limit < 1
  return false if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit > 5
  return false if !@applicable_exclusive_redeemables_limit.nil? && @applicable_exclusive_redeemables_limit < 1
  return false if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit > 30
  return false if !@applicable_exclusive_redeemables_per_category_limit.nil? && @applicable_exclusive_redeemables_per_category_limit < 1
  discount_calculation_mode_validator = EnumAttributeValidator.new('String', ["INITIAL_AMOUNT", "DISCOUNTED_AMOUNT"])
  return false unless discount_calculation_mode_validator.valid?(@discount_calculation_mode)
  redeemables_application_mode_validator = EnumAttributeValidator.new('String', ["ALL", "PARTIAL"])
  return false unless redeemables_application_mode_validator.valid?(@redeemables_application_mode)
  redeemables_sorting_rule_validator = EnumAttributeValidator.new('String', ["CATEGORY_HIERARCHY", "REQUESTED_ORDER"])
  return false unless redeemables_sorting_rule_validator.valid?(@redeemables_sorting_rule)
  redeemables_products_application_mode_validator = EnumAttributeValidator.new('String', ["STACK", "ONCE"])
  return false unless redeemables_products_application_mode_validator.valid?(@redeemables_products_application_mode)
  redeemables_no_effect_rule_validator = EnumAttributeValidator.new('String', ["REDEEM_ANYWAY", "SKIP"])
  return false unless redeemables_no_effect_rule_validator.valid?(@redeemables_no_effect_rule)
  redeemables_rollback_order_mode_validator = EnumAttributeValidator.new('String', ["WITH_ORDER", "WITHOUT_ORDER"])
  return false unless redeemables_rollback_order_mode_validator.valid?(@redeemables_rollback_order_mode)
  true
end