Class: VoucherifySdk::SegmentsGetResponseBody
- Inherits:
-
Object
- Object
- VoucherifySdk::SegmentsGetResponseBody
- Defined in:
- lib/VoucherifySdk/models/segments_get_response_body.rb
Overview
Response body schema for GET v1/segments/{segmentId}.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Timestamp representing the date and time when the segment was created.
-
#filter ⇒ Object
Defines a set of criteria for an
auto-updateorpassivesegment type. -
#id ⇒ Object
Unique segment ID.
-
#initial_sync_status ⇒ Object
Returns the value of attribute initial_sync_status.
-
#name ⇒ Object
Segment name.
-
#object ⇒ Object
The type of the object represented by JSON.
-
#type ⇒ Object
Defines whether the segment is: - Active (
auto-update): customers enter and leave the segment based on the defined filters and thecustomer.segment.enteredandcustomer.segment.leftevents are triggered, - Passive (passive): customers enter and leave the segment based on the defined filters, but thecustomer.segment.enteredandcustomer.segment.leftevents are not triggered, - Static (static): manually selected customers. -
#updated_at ⇒ Object
Timestamp in ISO 8601 format indicating when the segment was updated.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SegmentsGetResponseBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SegmentsGetResponseBody
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 113 def initialize(attributes = {}) # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'filter') self.filter = attributes[:'filter'] end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = 'segment' end if attributes.key?(:'initial_sync_status') self.initial_sync_status = attributes[:'initial_sync_status'] end end |
Instance Attribute Details
#created_at ⇒ Object
Timestamp representing the date and time when the segment was created. The value is shown in the ISO 8601 format.
26 27 28 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 26 def created_at @created_at end |
#filter ⇒ Object
Defines a set of criteria for an auto-update or passive segment type.
35 36 37 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 35 def filter @filter end |
#id ⇒ Object
Unique segment ID.
20 21 22 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 20 def id @id end |
#initial_sync_status ⇒ Object
Returns the value of attribute initial_sync_status.
40 41 42 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 40 def initial_sync_status @initial_sync_status end |
#name ⇒ Object
Segment name.
23 24 25 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 23 def name @name end |
#object ⇒ Object
The type of the object represented by JSON. This object stores information about the customer segment.
38 39 40 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 38 def object @object end |
#type ⇒ Object
Defines whether the segment is: - Active (auto-update): customers enter and leave the segment based on the defined filters and the customer.segment.entered and customer.segment.left events are triggered, - Passive (passive): customers enter and leave the segment based on the defined filters, but the customer.segment.entered and customer.segment.left events are not triggered, - Static (static): manually selected customers.
32 33 34 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 32 def type @type end |
#updated_at ⇒ Object
Timestamp in ISO 8601 format indicating when the segment was updated.
29 30 31 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 29 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 229 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = VoucherifySdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 79 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 65 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'type' => :'type', :'filter' => :'filter', :'object' => :'object', :'initial_sync_status' => :'initial_sync_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 98 def self.openapi_nullable Set.new([ :'id', :'name', :'created_at', :'updated_at', :'type', :'filter', :'object', :'initial_sync_status' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 84 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time', :'type' => :'String', :'filter' => :'Object', :'object' => :'String', :'initial_sync_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && created_at == o.created_at && updated_at == o.updated_at && type == o.type && filter == o.filter && object == o.object && initial_sync_status == o.initial_sync_status end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 300 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 198 def hash [id, name, created_at, updated_at, type, filter, object, initial_sync_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
276 277 278 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 276 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
270 271 272 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 270 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/VoucherifySdk/models/segments_get_response_body.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["auto-update", "passive", "static"]) return false unless type_validator.valid?(@type) object_validator = EnumAttributeValidator.new('String', ["segment"]) return false unless object_validator.valid?(@object) initial_sync_status_validator = EnumAttributeValidator.new('String', ["IN_PROGRESS", "DONE"]) return false unless initial_sync_status_validator.valid?(@initial_sync_status) true end |